#ifndef GTK_SERVER_PROTOCOL_H
#define GTK_SERVER_PROTOCOL_H

#ifdef  __cplusplus
extern "C" {
#endif

#include <stdint.h>
#include <stddef.h>
#include "wayland-server.h"

struct wl_client;
struct wl_resource;

struct gtk_shell1;
struct gtk_surface1;
struct wl_surface;

extern const struct wl_interface gtk_shell1_interface;
extern const struct wl_interface gtk_surface1_interface;

#ifndef GTK_SHELL1_CAPABILITY_ENUM
#define GTK_SHELL1_CAPABILITY_ENUM
enum gtk_shell1_capability {
	GTK_SHELL1_CAPABILITY_GLOBAL_APP_MENU = 1,
	GTK_SHELL1_CAPABILITY_GLOBAL_MENU_BAR = 2,
	GTK_SHELL1_CAPABILITY_DESKTOP_ICONS = 3,
};
#endif /* GTK_SHELL1_CAPABILITY_ENUM */

/**
 * gtk_shell1 - gtk specific extensions
 * @get_gtk_surface: (none)
 * @set_startup_id: (none)
 * @system_bell: (none)
 *
 * gtk_shell is a protocol extension providing additional features for
 * clients implementing it.
 */
struct gtk_shell1_interface {
	/**
	 * get_gtk_surface - (none)
	 * @gtk_surface: (none)
	 * @surface: (none)
	 */
	void (*get_gtk_surface)(struct wl_client *client,
				struct wl_resource *resource,
				uint32_t gtk_surface,
				struct wl_resource *surface);
	/**
	 * set_startup_id - (none)
	 * @startup_id: (none)
	 */
	void (*set_startup_id)(struct wl_client *client,
			       struct wl_resource *resource,
			       const char *startup_id);
	/**
	 * system_bell - (none)
	 * @surface: (none)
	 */
	void (*system_bell)(struct wl_client *client,
			    struct wl_resource *resource,
			    struct wl_resource *surface);
};

#define GTK_SHELL1_CAPABILITIES	0

#define GTK_SHELL1_CAPABILITIES_SINCE_VERSION	1

static inline void
gtk_shell1_send_capabilities(struct wl_resource *resource_, uint32_t capabilities)
{
	wl_resource_post_event(resource_, GTK_SHELL1_CAPABILITIES, capabilities);
}

struct gtk_surface1_interface {
	/**
	 * set_dbus_properties - (none)
	 * @application_id: (none)
	 * @app_menu_path: (none)
	 * @menubar_path: (none)
	 * @window_object_path: (none)
	 * @application_object_path: (none)
	 * @unique_bus_name: (none)
	 */
	void (*set_dbus_properties)(struct wl_client *client,
				    struct wl_resource *resource,
				    const char *application_id,
				    const char *app_menu_path,
				    const char *menubar_path,
				    const char *window_object_path,
				    const char *application_object_path,
				    const char *unique_bus_name);
	/**
	 * set_modal - (none)
	 */
	void (*set_modal)(struct wl_client *client,
			  struct wl_resource *resource);
	/**
	 * unset_modal - (none)
	 */
	void (*unset_modal)(struct wl_client *client,
			    struct wl_resource *resource);
	/**
	 * present - (none)
	 * @time: (none)
	 */
	void (*present)(struct wl_client *client,
			struct wl_resource *resource,
			uint32_t time);
};


#ifdef  __cplusplus
}
#endif

#endif
