/*
 * Copyright © 2014      Jonas Ådahl
 * Copyright © 2015      Red Hat Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice (including the next
 * paragraph) shall be included in all copies or substantial portions of the
 * Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

#ifndef RELATIVE_POINTER_UNSTABLE_V1_SERVER_PROTOCOL_H
#define RELATIVE_POINTER_UNSTABLE_V1_SERVER_PROTOCOL_H

#ifdef  __cplusplus
extern "C" {
#endif

#include <stdint.h>
#include <stddef.h>
#include "wayland-server.h"

struct wl_client;
struct wl_resource;

struct wl_pointer;
struct zwp_relative_pointer_manager_v1;
struct zwp_relative_pointer_v1;

extern const struct wl_interface zwp_relative_pointer_manager_v1_interface;
extern const struct wl_interface zwp_relative_pointer_v1_interface;

/**
 * zwp_relative_pointer_manager_v1 - get relative pointer objects
 * @destroy: destroy the relative pointer manager object
 * @get_relative_pointer: get a relative pointer object
 *
 * A global interface used for getting the relative pointer object for a
 * given pointer.
 */
struct zwp_relative_pointer_manager_v1_interface {
	/**
	 * destroy - destroy the relative pointer manager object
	 *
	 * Used by the client to notify the server that it will no longer
	 * use this relative pointer manager object.
	 */
	void (*destroy)(struct wl_client *client,
			struct wl_resource *resource);
	/**
	 * get_relative_pointer - get a relative pointer object
	 * @id: (none)
	 * @pointer: (none)
	 *
	 * Create a relative pointer interface given a wl_pointer object.
	 * See the wp_relative_pointer interface for more details.
	 */
	void (*get_relative_pointer)(struct wl_client *client,
				     struct wl_resource *resource,
				     uint32_t id,
				     struct wl_resource *pointer);
};


/**
 * zwp_relative_pointer_v1 - relative pointer object
 * @destroy: release the relative pointer object
 *
 * A wp_relative_pointer object is an extension to the wl_pointer
 * interface used for emitting relative pointer events. It shares the same
 * focus as wl_pointer objects of the same seat and will only emit events
 * when it has focus.
 */
struct zwp_relative_pointer_v1_interface {
	/**
	 * destroy - release the relative pointer object
	 *
	 * 
	 */
	void (*destroy)(struct wl_client *client,
			struct wl_resource *resource);
};

#define ZWP_RELATIVE_POINTER_V1_RELATIVE_MOTION	0

#define ZWP_RELATIVE_POINTER_V1_RELATIVE_MOTION_SINCE_VERSION	1

static inline void
zwp_relative_pointer_v1_send_relative_motion(struct wl_resource *resource_, uint32_t utime_hi, uint32_t utime_lo, wl_fixed_t dx, wl_fixed_t dy, wl_fixed_t dx_unaccel, wl_fixed_t dy_unaccel)
{
	wl_resource_post_event(resource_, ZWP_RELATIVE_POINTER_V1_RELATIVE_MOTION, utime_hi, utime_lo, dx, dy, dx_unaccel, dy_unaccel);
}

#ifdef  __cplusplus
}
#endif

#endif
